@@ -54,7 +54,7 @@ account_t *account_add( irc_t *irc, struct prpl *prpl, char *user, char *pass )
 	s = set_add( &a->set, "auto_reconnect", "true", set_eval_bool, a );
 	
 	s = set_add( &a->set, "password", NULL, set_eval_account, a );
-	s->flags |= ACC_SET_NOSAVE;
+	s->flags |= ACC_SET_NOSAVE | SET_NULL_OK;
 	
 	s = set_add( &a->set, "username", NULL, set_eval_account, a );
 	s->flags |= ACC_SET_NOSAVE | ACC_SET_OFFLINE_ONLY;
@@ -76,9 +76,23 @@ char *set_eval_account( set_t *set, char *value )
 	
 	/* Double-check: We refuse to edit on-line accounts. */
 	if( set->flags & ACC_SET_OFFLINE_ONLY && acc->ic )
-		return NULL;
+		return SET_INVALID;
 	
-	if( strcmp( set->key, "username" ) == 0 )
+	if( strcmp( set->key, "server" ) == 0 )
+	{
+		g_free( acc->server );
+		if( value && *value )
+		{
+			acc->server = g_strdup( value );
+			return value;
+		}
+		else
+		{
+			acc->server = g_strdup( set->def );
+			return g_strdup( set->def );
+		}
+	}
+	else if( strcmp( set->key, "username" ) == 0 )
 	{
 		g_free( acc->user );
 		acc->user = g_strdup( value );
@@ -86,34 +100,29 @@ char *set_eval_account( set_t *set, char *value )
 	}
 	else if( strcmp( set->key, "password" ) == 0 )
 	{
-		g_free( acc->pass );
-		acc->pass = g_strdup( value );
-		return NULL;	/* password shouldn't be visible in plaintext! */
-	}
-	else if( strcmp( set->key, "server" ) == 0 )
-	{
-		g_free( acc->server );
-		if( *value )
+		if( value )
 		{
-			acc->server = g_strdup( value );
-			return value;
+			g_free( acc->pass );
+			acc->pass = g_strdup( value );
+			return NULL;	/* password shouldn't be visible in plaintext! */
 		}
 		else
 		{
-			acc->server = NULL;
-			return g_strdup( set->def );
+			/* NULL can (should) be stored in the set_t
+			   variable, but is otherwise not correct. */
+			return SET_INVALID;
 		}
 	}
 	else if( strcmp( set->key, "auto_connect" ) == 0 )
 	{
 		if( !is_bool( value ) )
-			return NULL;
+			return SET_INVALID;
 		
 		acc->auto_connect = bool2int( value );
 		return value;
 	}
 	
-	return NULL;
+	return SET_INVALID;
 }
 
 account_t *account_get( irc_t *irc, char *id )
@@ -233,3 +242,83 @@ void account_off( irc_t *irc, account_t *a )
 		cancel_auto_reconnect( a );
 	}
 }
+
+struct account_reconnect_delay
+{
+	int start;
+	char op;
+	int step;
+	int max;
+};
+
+int account_reconnect_delay_parse( char *value, struct account_reconnect_delay *p )
+{
+	memset( p, 0, sizeof( *p ) );
+	/* A whole day seems like a sane "maximum maximum". */
+	p->max = 86400;
+	
+	/* Format: /[0-9]+([*+][0-9]+(<[0-9+]))/ */
+	while( *value && isdigit( *value ) )
+		p->start = p->start * 10 + *value++ - '0';
+	
+	/* Sure, call me evil for implementing my own fscanf here, but it's
+	   dead simple and I immediately know where to continue parsing. */
+	
+	if( *value == 0 )
+		/* If the string ends now, the delay is constant. */
+		return 1;
+	else if( *value != '+' && *value != '*' )
+		/* Otherwise allow either a + or a * */
+		return 0;
+	
+	p->op = *value++;
+	
+	/* + or * the delay by this number every time. */
+	while( *value && isdigit( *value ) )
+		p->step = p->step * 10 + *value++ - '0';
+	
+	if( *value == 0 )
+		/* Use the default maximum (one day). */
+		return 1;
+	else if( *value != '<' )
+		return 0;
+	
+	p->max = 0;
+	value ++;
+	while( *value && isdigit( *value ) )
+		p->max = p->max * 10 + *value++ - '0';
+	
+	return p->max > 0;
+}
+
+char *set_eval_account_reconnect_delay( set_t *set, char *value )
+{
+	struct account_reconnect_delay p;
+	
+	return account_reconnect_delay_parse( value, &p ) ? value : SET_INVALID;
+}
+
+int account_reconnect_delay( account_t *a )
+{
+	char *setting = set_getstr( &a->irc->set, "auto_reconnect_delay" );
+	struct account_reconnect_delay p;
+	
+	if( account_reconnect_delay_parse( setting, &p ) )
+	{
+		if( a->auto_reconnect_delay == 0 )
+			a->auto_reconnect_delay = p.start;
+		else if( p.op == '+' )
+			a->auto_reconnect_delay += p.step;
+		else if( p.op == '*' )
+			a->auto_reconnect_delay *= p.step;
+		
+		if( a->auto_reconnect_delay > p.max )
+			a->auto_reconnect_delay = p.max;
+	}
+	else
+	{
+		a->auto_reconnect_delay = 0;
+	}
+	
+	return a->auto_reconnect_delay;
+}
