@@ -147,11 +147,10 @@ conf_t *conf_load( int argc, char *argv[] )
 		}
 		else if( opt == 'R' )
 		{
-			/* We can't load the statefile yet (and should make very sure we do this
-			   only once), so set the filename here and load the state information
-			   when initializing ForkDaemon. (This option only makes sense in that
-			   mode anyway!) */
-			ipc_master_set_statefile( optarg );
+			/* Backward compatibility; older BitlBees passed this
+			   info using a command-line flag. Allow people to
+			   upgrade from such a version for now. */
+			setenv( "_BITLBEE_RESTART_STATE", optarg, 0 );
 		}
 		else if( opt == 'u' )
 		{
