@@ -28,7 +28,14 @@
 #include "base64.h"
 #include "arc.h"
 #include "md5.h"
+
+#if GLIB_CHECK_VERSION(2,8,0)
 #include <glib/gstdio.h>
+#else
+/* GLib < 2.8.0 doesn't have g_access, so just use the system access(). */
+#include <unistd.h>
+#define g_access access
+#endif
 
 typedef enum
 {
@@ -243,13 +250,14 @@ GMarkupParser xml_parser =
 
 static void xml_init( void )
 {
-	if( ! g_file_test( global.conf->configdir, G_FILE_TEST_EXISTS ) )
+	if( g_access( global.conf->configdir, F_OK ) != 0 )
 		log_message( LOGLVL_WARNING, "The configuration directory `%s' does not exist. Configuration won't be saved.", global.conf->configdir );
-	else if( ! g_file_test( global.conf->configdir, G_FILE_TEST_EXISTS ) || g_access( global.conf->configdir, W_OK ) != 0 )
+	else if( g_access( global.conf->configdir, F_OK ) != 0 || 
+	         g_access( global.conf->configdir, W_OK ) != 0 )
 		log_message( LOGLVL_WARNING, "Permission problem: Can't read/write from/to `%s'.", global.conf->configdir );
 }
 
-static storage_status_t xml_load_real( const char *my_nick, const char *password, irc_t *irc, xml_pass_st action )
+static storage_status_t xml_load_real( irc_t *irc, const char *my_nick, const char *password, xml_pass_st action )
 {
 	GMarkupParseContext *ctx;
 	struct xml_parsedata *xd;
@@ -257,9 +265,6 @@ static storage_status_t xml_load_real( const char *my_nick, const char *password
 	GError *gerr = NULL;
 	int fd, st;
 	
-	if( irc && irc->status & USTATUS_IDENTIFIED )
-		return( 1 );
-	
 	xd = g_new0( struct xml_parsedata, 1 );
 	xd->irc = irc;
 	xd->given_nick = g_strdup( my_nick );
@@ -311,21 +316,19 @@ static storage_status_t xml_load_real( const char *my_nick, const char *password
 	if( action == XML_PASS_CHECK_ONLY )
 		return STORAGE_OK;
 	
-	irc->status |= USTATUS_IDENTIFIED;
-	
 	return STORAGE_OK;
 }
 
-static storage_status_t xml_load( const char *my_nick, const char *password, irc_t *irc )
+static storage_status_t xml_load( irc_t *irc, const char *password )
 {
-	return xml_load_real( my_nick, password, irc, XML_PASS_UNKNOWN );
+	return xml_load_real( irc, irc->nick, password, XML_PASS_UNKNOWN );
 }
 
 static storage_status_t xml_check_pass( const char *my_nick, const char *password )
 {
 	/* This is a little bit risky because we have to pass NULL for the
 	   irc_t argument. This *should* be fine, if I didn't miss anything... */
-	return xml_load_real( my_nick, password, NULL, XML_PASS_CHECK_ONLY );
+	return xml_load_real( NULL, my_nick, password, XML_PASS_CHECK_ONLY );
 }
 
 static int xml_printf( int fd, int indent, char *fmt, ... )
@@ -361,18 +364,12 @@ static storage_status_t xml_save( irc_t *irc, int overwrite )
 	md5_byte_t pass_md5[21];
 	md5_state_t md5_state;
 	
-	if( irc->password == NULL )
-	{
-		irc_usermsg( irc, "Please register yourself if you want to save your settings." );
-		return STORAGE_OTHER_ERROR;
-	}
-	
 	path2 = g_strdup( irc->nick );
 	nick_lc( path2 );
 	g_snprintf( path, sizeof( path ) - 2, "%s%s%s", global.conf->configdir, path2, ".xml" );
 	g_free( path2 );
 	
-	if( !overwrite && g_file_test( path, G_FILE_TEST_EXISTS ) )
+	if( !overwrite && g_access( path, F_OK ) == 0 )
 		return STORAGE_ALREADY_EXISTS;
 	
 	strcat( path, "~" );
@@ -480,14 +477,18 @@ static gboolean xml_save_nick( gpointer key, gpointer value, gpointer data )
 
 static storage_status_t xml_remove( const char *nick, const char *password )
 {
-	char s[512];
+	char s[512], *lc;
 	storage_status_t status;
 
 	status = xml_check_pass( nick, password );
 	if( status != STORAGE_OK )
 		return status;
 
-	g_snprintf( s, 511, "%s%s%s", global.conf->configdir, nick, ".xml" );
+	lc = g_strdup( nick );
+	nick_lc( lc );
+	g_snprintf( s, 511, "%s%s%s", global.conf->configdir, lc, ".xml" );
+	g_free( lc );
+	
 	if( unlink( s ) == -1 )
 		return STORAGE_OTHER_ERROR;
 	
